﻿using Infragistics.Windows.DataPresenter;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace GroupBySummaries
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window, INotifyPropertyChanged
    {
        #region INotifyPropertyChanged Implementation
        public event PropertyChangedEventHandler PropertyChanged;
        protected void OnPropertyChanged(string propertyName)
        {
             if (PropertyChanged != null)
                 PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
        }
        #endregion

        // The only purpose for this property is to update the GroupByRecordPresenter text when needed.
        bool bUpdateSummaries = false;
        public bool UpdateSummaries
        {
            get { return bUpdateSummaries; }
            set
            {
                bUpdateSummaries = value;
                OnPropertyChanged("UpdateSummaries");
            }
        }

        public MainWindow()
        {
            InitializeComponent();
        }

        // If something updates the data which results in the summary value changing, this event will fire and let us know.
        private void xamDataGrid1_SummaryResultChanged(object sender, Infragistics.Windows.DataPresenter.Events.SummaryResultChangedEventArgs e)
        {
            // since a value changed, let's force the GroupByRecordPresenter text to update
            UpdateSummaries = true;
        }

        // This event fires when the summary selection control (the popup with the summary choices) is closed.  One of the event arguments will
        // tell me if the summaries actually changed or not.
        private void xamDataGrid1_SummarySelectionControlClosed(object sender, Infragistics.Windows.DataPresenter.Events.SummarySelectionControlClosedEventArgs e)
        {
            // if the summaries were changed then we need to update the GroupByRecordPresenter text
            if (e.SummariesChanged)
                UpdateSummaries = true;
        }
    }

    public class ConvertSummariesToText : IMultiValueConverter
    {
        public object Convert(object[] values, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            SummaryResultCollection summaryResults = (SummaryResultCollection)values[0];
            string summaryHeaderText = string.Empty;

            foreach (var summaryResult in summaryResults)
            {
                if ((summaryResult.DisplayAreaResolved & SummaryDisplayAreas.InGroupByRecords) != SummaryDisplayAreas.InGroupByRecords || 
                    summaryResult.Value == null)
                    continue;

                string fieldName = summaryResult.SourceField.Name;
                if (summaryResult.SourceField.Label != null && summaryResult.SourceField.Label.GetType() == typeof(string))
                    fieldName = (string)summaryResult.SourceField.Label;

                string calculatorName = summaryResult.SummaryDefinition.Calculator.DisplayName;
                string value = double.Parse(summaryResult.Value.ToString()).ToString("N");

                summaryHeaderText += calculatorName + "(" + fieldName + "): " + value + ", ";
            }

            return summaryHeaderText;
        }

        public object[] ConvertBack(object value, Type[] targetTypes, object parameter, System.Globalization.CultureInfo culture)
        {
            throw new NotImplementedException();
        }
    }

    public class SampleDataItem
    {
        public string name { get; set; }
        public string department { get; set; }
        public double salary { get; set; }
        public string email { get; set; }
    }

    public class SampleData : ObservableCollection<SampleDataItem>
    {
        public SampleData()
        {
            Add(new SampleDataItem { name = "Joe", department = "Sales", salary = 70000.0, email = "joe@email.com" });
            Add(new SampleDataItem { name = "Mary", department = "Engineering", salary = 71000.0, email = "mary@email.com" });
            Add(new SampleDataItem { name = "Jim", department = "Sales", salary = 72000.0, email = "jim@email.com" });
        }
    }
}
